#
# DNS Balance
#
# 雑用
#
# By: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>

# $Id: util.rb,v 1.2 2002/06/08 16:27:31 elca Exp $

# DNS パケット中の RR 名を人間に読みやすい形式に変換
def dnsstr_to_str(dnsstr)
  arr = []
  c = 0

  while TRUE
    if dnsstr[c] == 0
      break
    end
    arr.push(dnsstr[c+1, dnsstr[c]])
    c += dnsstr[c]+1
  end

  return arr.join(".")
end

# IP アドレス表記からそれに見合った4バイトの文字列を生成
#
# ex) "127.0.0.1" => "\x7f\x0\x0\x1"
def str_to_ipstr(str)
  arr = str.split(".").collect{|i| i.to_i}

  if arr.length != 4
    put_log("ipaddr invalid\n")
    exit(111)
  end

  return arr.pack("CCCC")
end

#
def min(a, b)
  return (if a < b then a else b end)
end

# end
